==> AnthropMMD_2.2.0.tar.gz: AnthropMMD/man/StartMMD.Rd <==
\name{StartMMD}
\alias{StartMMD}
\title{
The only function to use
}
\description{
Launches a Shiny Graphical User Interface for Mean Measure of Divergence.
}
\usage{
StartMMD()
}
\note{
The R console is not available when the GUI is active. To exit to GUI, type Echap (on MS Windows systems) or Ctrl+C (on Linux systems) in the R console.

On 14-inch (or smaller) screens, for convenience, it may be necessary to decrease the zoom level of your web browser and/or to turn on fullscreen mode.
}
\details{
The GUI of AnthropMMD is completely independent and autonomous. Reading the data file and specifying the parameters of the analysis are done through the interface. Once the dataset is loaded, the output reacts dynamically to any change in the analysis settings. 

\itemize{
\item AnthropMMD allows to read .CSV or .TXT data sets, but does not support .ODS or .XLS(X) files. Two types of files are accepted:
\itemize{
\item A \sQuote{Raw binary dataset} (one row per individual, one column per variable). The first column must be a factor indicating the group of each individual, and the other columns are binary data for the traits studied, where 1 indicates the presence of a trait in an individual, and 0 its absence. Row names are optional for this type of file. An example of valid datafile can be found here: \url{http://tinyurl.com/RawBinaryMMD}
\item A \sQuote{Table of n's and absolute frequencies for each group}, i.e. a dataset of sample sizes and absolute frequencies. This type of dataset has \eqn{2 \times K}{2*K} rows (\eqn{K}{K} being the number of groups compared) and \eqn{p}{p} columns (\eqn{p}{p} being the number of traits studied). The first \eqn{K}{K} lines must be the group n's for each trait, and the last \eqn{K}{K} lines are absolute frequencies for each trait (i.e. the number of times the trait is present). Row names are mandatory for this type of file. The first \eqn{K}{K} rows must be labelled with names beginning with \sQuote{N_}, such as: N_GroupA, N_GroupB, ..., N_GroupK. The last \eqn{K}{K} rows should be labelled with names beginning with \sQuote{Freq_}, such as: Freq_GroupA, ..., Freq_GroupK. An example of valid datafile can be found here: \url{http://tinyurl.com/TableFreqMMD}
}
For both data types, column names are strongly recommended for better interpretability of the results. 

\item The analysis could be done with all groups/populations in the datafile (default), or some of them can be excluded (for example because of their very small sample sizes for most traits).

\item One can choose between Anscombe or Freeman-Tukey formula for angular transformation (cf. Harris and Sjovold 2004; Irish 2010).
\item \sQuote{Only retain the traits with this minimal number of individuals per group}: the traits with fewer indivuals in at least one active group will not be considered in the analysis.
\item \sQuote{Exclusion strategy}: a good selection of traits is crucial when using MMD (cf. Harris and Sjovold 2004 for a complete explanation), and the user should probably choose to exclude some traits with very few variability across groups. 
\itemize{
\item \sQuote{Exclude nonpolymorphic traits} allows to remove all the traits showing no variability at all, i.e. with the same value (always 0, or always 1) for all the individuals. 
\item \sQuote{Exclude quasi-nonpolymorphic traits} also removes the traits whose variability is only due to a single individual: for example, a trait with only one positive observation in the whole dataset. 
\item \sQuote{Use Fisher's exact test} implements the advice given by Harris and Sjovold (2004) to select contributory traits, defined as those \dQuote{showing a statistically significant difference between at least one pair of the groups being evaluated}. Fisher's exact tests are performed for each pair of groups, and the traits showing no intergroup difference at all are excluded. Note that if you have a large number of groups (say, 10 groups), a trait with strictly equal frequencies for the last 8 groups may be considered as useful according to this criterion if there is a significant difference for the first two groups. This criterion will select all traits that can be useful for a given pair of groups, even if they are nondiscriminatory for all the other ones.
\item \sQuote{Exclude traits with negative overall MD} is a simple way of removing the traits with quite similar frequencies across groups (the 'overall MD' is defined as the sum of the variable's measures of divergence over all pairs of groups). This criterion tends to select the traits whose frequency differs substantially across most or all groups.
}
These four options are designed to avoid negative MMD values, which have have no biological meaning.
\item Some groups/populations can be manually excluded from the analysis. This may be useful if very few individuals belonging to a given population could be recorded for the variables retained by the criteria described above.

\item A MDS plot and a hierarchical clustering, done using MMD dissimilarities as an input, are given in the last two tabs. As MMD can sometimes be negative, those negatives values are replaced by zeros, so that the MMD matrix can really be seen as a symmetrical distance matrix. Please note that the MDS cannot be displayed if there is only one postive eigenvalue.
}
}
\value{
The function returns no value by itself, but all results can be indivudally downloaded through the graphical interface.

\itemize{
\item The \sQuote{true} MMD values (i.e., which can be negative in the precise case of small samples with similar traits frequencies, cf. Irish 2010) and their standard deviations are presentend in the matrix labeled \sQuote{MMD values (upper triangular part) and associated SD values (lower triangular part)}.
\item A MMD can be considered as significant if it is greater than twice its standard deviation. Significance is assessed in another ad-hoc table of results.
\item The negative MMD values, if any, are replaced by zeros in the \sQuote{Symmetrical matrix of MMD values}.
}
}
\references{
Sjovold, T. (1977). Non-metrical Divergence Between Skeletal Populations. Ossa, \bold{4}, Supp. 1.

Harris, E. F. and Sjovold, T. (2004). Calculation of Smith's Mean Measure of Divergence for Intergroup Comparisons Using Nonmetric Data. Dental Anthropology, \bold{17}(3), 83--93.

Irish, J. (2010). The Mean Measure of Divergence: Its Utility in Model-Free and Model-Bound Analyses Relative to the Mahalanobis D2 Distance for Nonmetric Traits. American Journal of Human Biology, \bold{22}, 378--395.

Nikita, E. (2015). A Critical Review of the Mean Measure of Divergence and Mahalanobis Distances Using Artificial Data and New Approaches to the Estimation of Biodistances Employing Nonmetric Traits. American Journal of Physical Anthropology, \bold{157}, 284--294.
}
\author{
Frederic Santos, <frederic.santos@u-bordeaux.fr>
}
\examples{
\dontrun{ StartMMD()}
}

==> AnthropMMD_2.2.1.tar.gz: AnthropMMD/man/StartMMD.Rd <==
\name{StartMMD}
\alias{StartMMD}
\title{
An RShiny app for the MMD
}
\description{
Launches a Shiny Graphical User Interface for the calculation of the Mean Measure of Divergence.
}
\usage{
StartMMD()
}
\note{
The R console is not available when the GUI is active. To exit to GUI, type Echap (on MS Windows systems) or Ctrl+C (on Linux systems) in the R console.

On 14-inch (or smaller) screens, for convenience, it may be necessary to decrease the zoom level of your web browser and/or to turn on fullscreen mode.
}
\details{
The GUI of AnthropMMD is completely independent and autonomous. Reading the data file and specifying the parameters of the analysis are done through the interface. Once the dataset is loaded, the output reacts dynamically to any change in the analysis settings. 

\itemize{
\item AnthropMMD allows to read .CSV or .TXT data sets, but does not support .ODS or .XLS(X) files. Two types of files are accepted:
\itemize{
\item A \sQuote{Raw binary dataset} (one row per individual, one column per variable). The first column must be a factor indicating the group of each individual, and the other columns are binary data for the traits studied, where 1 indicates the presence of a trait in an individual, and 0 its absence. Row names are optional for this type of file. An example of valid datafile can be found here: \url{http://tinyurl.com/RawBinaryMMD}
\item A \sQuote{Table of n's and absolute frequencies for each group}, i.e. a dataset of sample sizes and absolute frequencies. This type of dataset has \eqn{2 \times K}{2*K} rows (\eqn{K}{K} being the number of groups compared) and \eqn{p}{p} columns (\eqn{p}{p} being the number of traits studied). The first \eqn{K}{K} lines must be the group n's for each trait, and the last \eqn{K}{K} lines are absolute frequencies for each trait (i.e. the number of times the trait is present). Row names are mandatory for this type of file. The first \eqn{K}{K} rows must be labelled with names beginning with \sQuote{N_}, such as: N_GroupA, N_GroupB, ..., N_GroupK. The last \eqn{K}{K} rows should be labelled with names beginning with \sQuote{Freq_}, such as: Freq_GroupA, ..., Freq_GroupK. An example of valid datafile can be found here: \url{http://tinyurl.com/TableFreqMMD}
}
For both data types, column names are strongly recommended for better interpretability of the results. 

\item The analysis could be done with all groups/populations in the datafile (default), or some of them can be excluded (for example because of their very small sample sizes for most traits).

\item One can choose between Anscombe or Freeman-Tukey formula for angular transformation (cf. Harris and Sjovold 2004; Irish 2010).
\item \sQuote{Only retain the traits with this minimal number of individuals per group}: the traits with fewer indivuals in at least one active group will not be considered in the analysis.
\item \sQuote{Exclusion strategy}: a good selection of traits is crucial when using MMD (cf. Harris and Sjovold 2004 for a complete explanation), and the user should probably choose to exclude some traits with very few variability across groups. 
\itemize{
\item \sQuote{Exclude nonpolymorphic traits} allows to remove all the traits showing no variability at all, i.e. with the same value (always 0, or always 1) for all the individuals. 
\item \sQuote{Exclude quasi-nonpolymorphic traits} also removes the traits whose variability is only due to a single individual: for example, a trait with only one positive observation in the whole dataset. 
\item \sQuote{Use Fisher's exact test} implements the advice given by Harris and Sjovold (2004) to select contributory traits, defined as those \dQuote{showing a statistically significant difference between at least one pair of the groups being evaluated}. Fisher's exact tests are performed for each pair of groups, and the traits showing no intergroup difference at all are excluded. Note that if you have a large number of groups (say, 10 groups), a trait with strictly equal frequencies for the last 8 groups may be considered as useful according to this criterion if there is a significant difference for the first two groups. This criterion will select all traits that can be useful for a given pair of groups, even if they are nondiscriminatory for all the other ones.
\item \sQuote{Exclude traits with negative overall MD} is a simple way of removing the traits with quite similar frequencies across groups (the 'overall MD' is defined as the sum of the variable's measures of divergence over all pairs of groups). This criterion tends to select the traits whose frequency differs substantially across most or all groups.
}
These four options are designed to avoid negative MMD values, which have no biological meaning.
\item Some groups/populations can be manually excluded from the analysis. This may be useful if very few individuals belonging to a given population could be recorded for the variables retained by the criteria described above.

\item A MDS plot and a hierarchical clustering, done using MMD dissimilarities as an input, are given in the last two tabs. As MMD can sometimes be negative, those negatives values are replaced by zeros, so that the MMD matrix can really be seen as a symmetrical distance matrix. Please note that the MDS cannot be displayed if there is only one postive eigenvalue.
}
}
\value{
The function returns no value by itself, but all results can be indivudally downloaded through the graphical interface.

\itemize{
\item The \sQuote{true} MMD values (i.e., which can be negative in the precise case of small samples with similar traits frequencies, cf. Irish 2010) and their standard deviations are presentend in the matrix labeled \sQuote{MMD values (upper triangular part) and associated SD values (lower triangular part)}.
\item A MMD can be considered as significant if it is greater than twice its standard deviation. Significance is assessed in another ad-hoc table of results.
\item The negative MMD values, if any, are replaced by zeros in the \sQuote{Symmetrical matrix of MMD values}.
}
}
\references{
Sjovold, T. (1977). Non-metrical Divergence Between Skeletal Populations. Ossa, \bold{4}, Supp. 1.

Harris, E. F. and Sjovold, T. (2004). Calculation of Smith's Mean Measure of Divergence for Intergroup Comparisons Using Nonmetric Data. Dental Anthropology, \bold{17}(3), 83--93.

Irish, J. (2010). The Mean Measure of Divergence: Its Utility in Model-Free and Model-Bound Analyses Relative to the Mahalanobis D2 Distance for Nonmetric Traits. American Journal of Human Biology, \bold{22}, 378--395.

Nikita, E. (2015). A Critical Review of the Mean Measure of Divergence and Mahalanobis Distances Using Artificial Data and New Approaches to the Estimation of Biodistances Employing Nonmetric Traits. American Journal of Physical Anthropology, \bold{157}, 284--294.
}
\author{
Frederic Santos, <frederic.santos@u-bordeaux.fr>
}
\examples{
\dontrun{ StartMMD()}
}
